Crate liminal_ark_poseidon

Crate liminal_ark_poseidon 

Modules

hash
Hashing raw field elements.

Structs

BigInteger256
Numeric type reexported from ark_ff.

Constants

DOMAIN_SEPARATOR
Poseidon paper suggests using domain separation for concretely encoding the use case in the capacity element (which is fine as it is 256 bits large and has a lot of bits to fill).

Functions

domain_separator
Return DOMAIN_SEPARATOR as a field element.

Type Aliases

Fr
Circuit field reexported from ark_bls12_381.